==> jsts-1.6.2.jar: META-INF/resources/webjars/jsts/1.6.2/org/locationtech/jts/geom/prep/PreparedPolygonPredicate.js <==
import Location from '../Location';
import extend from '../../../../../extend';
import ComponentCoordinateExtracter from '../util/ComponentCoordinateExtracter';
import SimplePointInAreaLocator from '../../algorithm/locate/SimplePointInAreaLocator';
export default function PreparedPolygonPredicate() {
	this._prepPoly = null;
	this._targetPointLocator = null;
	let prepPoly = arguments[0];
	this._prepPoly = prepPoly;
	this._targetPointLocator = prepPoly.getPointLocator();
}
extend(PreparedPolygonPredicate.prototype, {
	isAnyTargetComponentInAreaTest: function (testGeom, targetRepPts) {
		var piaLoc = new SimplePointInAreaLocator(testGeom);
		for (var i = targetRepPts.iterator(); i.hasNext(); ) {
			var p = i.next();
			var loc = piaLoc.locate(p);
			if (loc !== Location.EXTERIOR) return true;
		}
		return false;
	},
	isAllTestComponentsInTarget: function (testGeom) {
		var coords = ComponentCoordinateExtracter.getCoordinates(testGeom);
		for (var i = coords.iterator(); i.hasNext(); ) {
			var p = i.next();
			var loc = this._targetPointLocator.locate(p);
			if (loc === Location.EXTERIOR) return false;
		}
		return true;
	},
	isAnyTestComponentInTargetInterior: function (testGeom) {
		var coords = ComponentCoordinateExtracter.getCoordinates(testGeom);
		for (var i = coords.iterator(); i.hasNext(); ) {
			var p = i.next();
			var loc = this._targetPointLocator.locate(p);
			if (loc === Location.INTERIOR) return true;
		}
		return false;
	},
	isAllTestComponentsInTargetInterior: function (testGeom) {
		var coords = ComponentCoordinateExtracter.getCoordinates(testGeom);
		for (var i = coords.iterator(); i.hasNext(); ) {
			var p = i.next();
			var loc = this._targetPointLocator.locate(p);
			if (loc !== Location.INTERIOR) return false;
		}
		return true;
	},
	isAnyTestComponentInTarget: function (testGeom) {
		var coords = ComponentCoordinateExtracter.getCoordinates(testGeom);
		for (var i = coords.iterator(); i.hasNext(); ) {
			var p = i.next();
			var loc = this._targetPointLocator.locate(p);
			if (loc !== Location.EXTERIOR) return true;
		}
		return false;
	},
	interfaces_: function () {
		return [];
	},
	getClass: function () {
		return PreparedPolygonPredicate;
	}
});

==> jsts-2.0.3.jar: META-INF/resources/webjars/jsts/2.0.3/org/locationtech/jts/geom/prep/PreparedPolygonPredicate.js <==
import Location from '../Location';
import ComponentCoordinateExtracter from '../util/ComponentCoordinateExtracter';
import SimplePointInAreaLocator from '../../algorithm/locate/SimplePointInAreaLocator';
export default class PreparedPolygonPredicate {
	constructor() {
		PreparedPolygonPredicate.constructor_.apply(this, arguments);
	}
	isAnyTargetComponentInAreaTest(testGeom, targetRepPts) {
		var piaLoc = new SimplePointInAreaLocator(testGeom);
		for (var i = targetRepPts.iterator(); i.hasNext(); ) {
			var p = i.next();
			var loc = piaLoc.locate(p);
			if (loc !== Location.EXTERIOR) return true;
		}
		return false;
	}
	isAllTestComponentsInTarget(testGeom) {
		var coords = ComponentCoordinateExtracter.getCoordinates(testGeom);
		for (var i = coords.iterator(); i.hasNext(); ) {
			var p = i.next();
			var loc = this._targetPointLocator.locate(p);
			if (loc === Location.EXTERIOR) return false;
		}
		return true;
	}
	isAnyTestComponentInTargetInterior(testGeom) {
		var coords = ComponentCoordinateExtracter.getCoordinates(testGeom);
		for (var i = coords.iterator(); i.hasNext(); ) {
			var p = i.next();
			var loc = this._targetPointLocator.locate(p);
			if (loc === Location.INTERIOR) return true;
		}
		return false;
	}
	isAllTestComponentsInTargetInterior(testGeom) {
		var coords = ComponentCoordinateExtracter.getCoordinates(testGeom);
		for (var i = coords.iterator(); i.hasNext(); ) {
			var p = i.next();
			var loc = this._targetPointLocator.locate(p);
			if (loc !== Location.INTERIOR) return false;
		}
		return true;
	}
	isAnyTestComponentInTarget(testGeom) {
		var coords = ComponentCoordinateExtracter.getCoordinates(testGeom);
		for (var i = coords.iterator(); i.hasNext(); ) {
			var p = i.next();
			var loc = this._targetPointLocator.locate(p);
			if (loc !== Location.EXTERIOR) return true;
		}
		return false;
	}
	getClass() {
		return PreparedPolygonPredicate;
	}
	get interfaces_() {
		return [];
	}
}
PreparedPolygonPredicate.constructor_ = function () {
	this._prepPoly = null;
	this._targetPointLocator = null;
	let prepPoly = arguments[0];
	this._prepPoly = prepPoly;
	this._targetPointLocator = prepPoly.getPointLocator();
};
